@@ -15,9 +15,13 @@ def import_figshare(limit):
 
 @click.command()
 @click.option('--limit', default=0, help='Limit number of datasets imported')
-def import_internal(limit):
+@click.option('--start-date', default="2000-01-01",
+              help='Import datasets in the depot starting from a given date')
+@click.option('--end-date', default="3000-01-01",
+              help='Import datasets in the depot only until a given date')
+def import_internal(limit, start_date="2000-01-01", end_date="3000-01-01"):
     """Import internal data located in /data/depots/internal"""
-    internal(limit=limit)
+    internal(limit=limit, start_date=start_date, end_date=end_date)
 
 
 @click.command()
